// @flow

import React, { setState, useState, memo } from "react"
import { makeStyles } from "@mui/styles"
import { createTheme, ThemeProvider } from "@mui/material/styles"
import SidebarBoxContainer from "../SidebarBoxContainer"
import HistoryIcon from "@mui/icons-material/History"
import List from "@mui/material/List"
import ListItem from "@mui/material/ListItem"
import ListItemText from "@mui/material/ListItemText"
import IconButton from "@mui/material/IconButton"
import ListItemSecondaryAction from "@mui/material/ListItemSecondaryAction"
import UndoIcon from "@mui/icons-material/Undo"
import moment from "moment"
import { grey } from "@mui/material/colors"
import isEqual from "lodash/isEqual"
import Box from "@mui/material/Box"

const theme = createTheme()
const useStyles = makeStyles((theme) => ({
  emptyText: {
    fontSize: 14,
    fontWeight: "bold",
    color: grey[500],
    textAlign: "center",
    padding: 20,
  },
}))

const listItemTextStyle = { paddingLeft: 16 }

export const ImageTagSidebarBox = ({
  history,
  onRestoreHistory,
}: {
  history: Array<{ name: string, time: Date }>,
}) => {
  const [radioTag, setRadioTag] = useState(null)
  const [saveTag, setSaveTag] = useState(null)

  const onChangeRadioTag = (e) => {
    setRadioTag(e.target.value)
  }

  const onSaveTag = (e) => {
    e.preventDefault()
    setSaveTag(radioTag)
  }

  return (
    <ThemeProvider theme={theme}>
      <SidebarBoxContainer title="TAG" icon expandedByDefault={true}>
        <div
          style={{
            height: "120px",
            width: "220px",
            border: "1px solid rgba(0, 0, 0, 0.3)",
            borderRadius: "5px",
            margin: "auto",
            padding: "20px",
          }}
          onChange={onChangeRadioTag}
        >
          <input
            type="radio"
            style={{
              accentColor: "#27AE60",
              marginRight: "5px",
            }}
            name="good"
            value="good"
          />
          <label for="specifyColor">Good</label>
          <br />
          <input
            type="radio"
            style={{
              accentColor: "#27AE60",
              marginTop: "10px",
              marginRight: "5px",
            }}
            name="good"
            value="good"
          />
          <label for="specifyColor">Bad</label>
          <br />
          <input
            type="radio"
            style={{
              accentColor: "#27AE60",
              marginTop: "10px",
              marginRight: "5px",
            }}
            name="good"
            value="good"
          />
          <label for="specifyColor">Ignore</label>
          <br />
          <button
            style={{
              padding: "8px",
              float: "right",
              backgroundColor: "#27AE60",
              border: "none",
              color: "white",
              borderRadius: "2px",
            }}
            onClick={onSaveTag}
          >
            Save
          </button>
        </div>
      </SidebarBoxContainer>
    </ThemeProvider>
  )
}

export default memo(ImageTagSidebarBox, (prevProps, nextProps) =>
  isEqual(
    prevProps.history.map((a) => [a.name, a.time]),
    nextProps.history.map((a) => [a.name, a.time])
  )
)
